from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class MA(PredefinedNamespace):
    """Ontology for Media Resources 1.0"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/ma-ont.ttl

    _nsBaseIri = "http://www.w3.org/ns/ma-ont#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Agent: NamedNode
    """A person or organisation contributing to the media resource."""
    AudioTrack: NamedNode
    """A specialisation of Track for Audio to provide a link to specific data properties such as sampleRate, etc. Specialisation is defined through object properties."""
    Collection: NamedNode
    """Any group of media resource e.g. a series."""
    DataTrack: NamedNode
    """Ancillary data track e.g. captioning  in addition to video and audio tracks. Specialisation is made through the use of appropriate object properties."""
    Image: NamedNode
    """A still image / thumbnail / key frame related to the media resource or being the media resource itself."""
    Location: NamedNode
    """A location related to the media resource, e.g. depicted in the resource (possibly fictional) or where the resource was created (shooting location), etc."""
    MediaFragment: NamedNode
    """A media fragment (spatial, temporal, track...) composing a media resource. In other ontologies fragment is sometimes referred to as a 'part' or 'segment'."""
    MediaResource: NamedNode
    """An image or an audiovisual media resource, which can be composed of one or more fragment / track."""
    Organisation: NamedNode
    """An organisation or moral agent."""
    Person: NamedNode
    """A physical person."""
    Rating: NamedNode
    """Information about the rating given to a media resource."""
    TargetAudience: NamedNode
    """Information about The target audience (target region, target audience category but also parental guidance recommendation) for which a media resource is intended."""
    Track: NamedNode
    """A specialisation of MediaFragment for audiovisual content."""
    VideoTrack: NamedNode
    """A specialisation of Track for Video to provide a link to specific data properties such as frameRate, etc. Signing is another possible example of video track. Specialisation is defined through object properties."""
    alternativeTitle: NamedNode
    """Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "alternative"."""
    averageBitRate: NamedNode
    """Corresponds to 'averageBitRate' in the Ontology for Media Resources, expressed in kilobits/second."""
    collectionName: NamedNode
    """The name by which a collection (e.g. series) is known."""
    copyright: NamedNode
    """Corresponds to 'copyright.copyright' in the Ontology for Media Resources."""
    createdIn: NamedNode
    """A subproperty of 'hasRelatedLocation" used to specify where material shooting took place."""
    creationDate: NamedNode
    """Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "creationDate"."""
    date: NamedNode
    """Corresponds to date.date in the ontology for Media Resources. Subproperties can be used to distinguish different values of 'date.type'. The recommended range is 'xsd:dateTime' (for compliance with OWL2-QL and OWL2-RL) but other time-related datatypes may be used (e.g. 'xsd:gYear', 'xsd:date'...)."""
    depictsFictionalLocation: NamedNode
    """A subproperty of 'hasRelatedLocation' used to specify where the action depicted in the media is supposed to take place, as opposed to the location where shooting actually took place (see 'createdIn')."""
    description: NamedNode
    """Corresponds to 'description' in the Ontology for Media Resources. This can be specialised by using sub-properties e.g. 'summary' or 'script'."""
    duration: NamedNode
    """Corresponds to 'duration' in the Ontology for Media Resources."""
    editDate: NamedNode
    """Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "editDate"."""
    features: NamedNode
    """Corresponds to 'contributor.contributor' in the Ontology for Media Resources with a 'contributor.role' meaning "actor"."""
    fragmentName: NamedNode
    """Corresponds to 'namedFragment.label' in the Ontology for Media Resources."""
    frameHeight: NamedNode
    """Corresponds to 'frameSize.height' in the Ontology for Media Resources, measured in frameSizeUnit."""
    frameRate: NamedNode
    """Corresponds to 'frameRate' in the Ontology for Media Resources, in frame per second."""
    frameSizeUnit: NamedNode
    """Corresponds to 'frameSize.unit' in the Ontology for Media Resources."""
    frameWidth: NamedNode
    """Corresponds to 'frameSize.width' in the Ontology for Media Resources measured in frameSizeUnit."""
    hasAccessConditions: NamedNode
    """Corresponds to 'policy' in the Ontology for Media Resources with a 'policy.type' "access conditions"."""
    hasAudioDescription: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "audio-description"."""
    hasCaptioning: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "captioning". This property can for example point to a spatial fragment, a VideoTrack or a DataTrack. The language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track."""
    hasChapter: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "chapter"."""
    hasClassification: NamedNode
    """Corresponds to 'targetAudience.classification' in the Ontology for Media Resources. This property is used to provide a value characterising the target audience."""
    hasClassificationSystem: NamedNode
    """Corresponds to 'targetAudience.identifier' in the Ontology for Media Resources. This is used to identify the reference sheme against which the target audience has been characterised."""
    hasCompression: NamedNode
    """Corresponds to 'compression' in the Ontology for Media Resources."""
    hasContributor: NamedNode
    """Corresponds to 'contributor.contributor' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'contributor.role'."""
    hasCreator: NamedNode
    """Corresponds to 'creator.creator' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'creator.role'. Note that this property is semantically a subproperty of 'hasContributor'."""
    hasFormat: NamedNode
    """Corresponds to 'format' in the Ontology for Media Resources."""
    hasFragment: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'fragment.role'."""
    hasGenre: NamedNode
    """Corresponds to 'genre' in the Ontology for Media Resources."""
    hasKeyword: NamedNode
    """Corresponds to 'keyword' in the Ontology for Media Resources."""
    hasLanguage: NamedNode
    """Corresponds to 'language' in the Ontology for Media Resources. The language used in the resource. A controlled vocabulary such as defined in BCP 47 SHOULD be used. This property can also be used to identify the presence of sign language (RFC 5646). By inheritance, the hasLanguage property applies indifferently at the media resource / fragment / track levels.  Best practice recommends to use to best possible level of granularity fo describe the usage of language within a media resource including at fragment and track levels."""
    hasLocationCoordinateSystem: NamedNode
    """Corresponds to 'location.coordinateSystem' in the Ontology for Media Resources."""
    hasNamedFragment: NamedNode
    """Corresponds to 'namedFragment' in the Ontology for Media Resources."""
    hasPermissions: NamedNode
    """Corresponds to 'policy' in the Ontology for Media Resources with a  'policy.type' meaning "permissions"."""
    hasPolicy: NamedNode
    """Corresponds to 'policy' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'policy.type'."""
    hasPublisher: NamedNode
    """Corresponds to 'publisher' in the Ontology for Media Resources."""
    hasRating: NamedNode
    """Corresponds to 'rating' in the Ontology for Media Resources."""
    hasRatingSystem: NamedNode
    """Corresponds to 'rating.type' in the Ontology for Media Resources."""
    hasRelatedImage: NamedNode
    """Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "related image"."""
    hasRelatedLocation: NamedNode
    """Corresponds to 'location' in the Ontology for Media Resources. Subproperties are provided to specify, when possible, the relation between the media resource and the location."""
    hasRelatedResource: NamedNode
    """Corresponds to 'relation' and in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'relation.type'."""
    hasSigning: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "signing". This property can for example point to a spatial fragment or a VideoTrack. The sign language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track."""
    hasSource: NamedNode
    """Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "source"."""
    hasSubtitling: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "subtitling"."""
    hasTargetAudience: NamedNode
    """Corresponds to 'targetAudience' in the Ontology for Media Resources."""
    hasTrack: NamedNode
    """Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "track"."""
    isCopyrightedBy: NamedNode
    """Corresponds to 'copyright.identifier' in the Ontology for Media Resources."""
    isMemberOf: NamedNode
    """Corresponds to 'collection' in the Ontology for Media Resources."""
    isProvidedBy: NamedNode
    """Corresponds to 'rating.identifier' in the Ontology for Media Resources."""
    locationAltitude: NamedNode
    """Corresponds to 'location.altitude' in the Ontology for Media Resources."""
    locationLatitude: NamedNode
    """Corresponds to 'location.latitude' in the Ontology for Media Resources."""
    locationLongitude: NamedNode
    """Corresponds to 'location.longitude' in the Ontology for Media Resources."""
    locationName: NamedNode
    """Corresponds to 'location.name' in the Ontology for Media Resources."""
    locator: NamedNode
    """Corresponds to 'locator' in the Ontology for Media Resources."""
    mainOriginalTitle: NamedNode
    """Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "original"."""
    numberOfTracks: NamedNode
    """Corresponds to 'numTracks.number' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'numTracks.type'."""
    ratingScaleMax: NamedNode
    """Corresponds to 'rating.max' in the Ontology for Media Resources."""
    ratingScaleMin: NamedNode
    """Corresponds to 'rating.min' in the Ontology for Media Resources."""
    ratingValue: NamedNode
    """Corresponds to 'rating.value' in the Ontology for Media Resources."""
    recordDate: NamedNode
    """Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "recordDate"."""
    releaseDate: NamedNode
    """Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "releaseDate"."""
    samplingRate: NamedNode
    """Corresponds to 'samplingRate' in the Ontology for Media Resources, in samples per second."""
    title: NamedNode
    """Corresponds to 'title.title' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'title.type'."""
    trackName: NamedNode
    """Corresponds to 'fragment.name' in the Ontology for Media Resources, for Track fragments."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DCAM(PredefinedNamespace):
    """Dublin Core Abstract Model for vocabulary description"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.dublincore.org/specifications/dublin-core/dcmi-terms/dublin_core_abstract_model.nt

    _nsBaseIri = "http://purl.org/dc/dcam/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    VocabularyEncodingScheme: NamedNode
    """An enumerated set of resources."""
    domainIncludes: NamedNode
    """A suggested class for subjects of this property."""
    memberOf: NamedNode
    """A relationship between a resource and a vocabulary encoding scheme which indicates that the resource is a member of a set."""
    rangeIncludes: NamedNode
    """A suggested class for values of this property."""



import csv
import datetime as dt
import keyword
import urllib.request
from dataclasses import dataclass
from string import Template
from sys import stderr

import pyoxigraph  # noqa
from pyoxigraph import Literal, NamedNode, RdfFormat, Store

type DescMapping = dict[NamedNode, Literal]


@dataclass
class PredefinedClass:
    nsIRI: str  # base namespace, conceptual source
    downloadFormat: RdfFormat | None  # format to parse downloaded file as
    issueWarnings: bool = False  # issue warnings if the local name is unknown
    sourceIRI: str | None = None  # overrides iri, if defined
    hasContainerMembershipProperties: bool = False
    title: str = ""


def load_from_url(info: PredefinedClass) -> DescMapping:
    if info.downloadFormat is None:
        raise ValueError("Cannot attempt to download file without format")

    # Download and parse the original source file
    req = urllib.request.Request(info.sourceIRI or info.nsIRI)
    req.add_header("Accept", "*/*")
    req.add_header("User-Agent", "curl/8.7.1")
    f = urllib.request.urlopen(req)
    store = Store()
    store.load(f, info.downloadFormat, base_iri=info.nsIRI)

    # Get all defined localnames, whether as subject, predicate or object.
    lnames = set()
    filter_subjects = Template("""
        SELECT ?lname WHERE {
            { ?lname ?p ?o . FILTER ( STRSTARTS(str(?lname), "$BASE" ) ) } UNION
            { ?s ?lname ?o . FILTER ( STRSTARTS(str(?lname), "$BASE" ) ) } UNION
            { ?s ?p ?lname . FILTER ( STRSTARTS(str(?lname), "$BASE" ) ) } 
        }
    """).substitute({"BASE": info.nsIRI})

    q = store.query(filter_subjects)  # type: ignore
    q = q  # type: pyoxigraph.QuerySolution
    for row in q:
        lnames.add(row["lname"])

    lname_docstring: DescMapping = dict()

    # Get docstrings of all those lnames
    for lname in lnames:
        get_docstring = Template("""
PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>

SELECT DISTINCT ?docstring WHERE {
  $this rdfs:comment|skos:definition ?ds .

  # The language has to be either EN or have no language tag
  FILTER ( LANGMATCHES(LANG(?ds), "en") || LANG(?ds) = '')

  BIND (?ds AS ?docstring)
}
limit 10

                        """).substitute({"this": lname})
        q = store.query(get_docstring)  # type: ignore
        q = q  # type: pyoxigraph.QuerySolution
        for row in q:
            lname_docstring[lname] = row["docstring"]

    return lname_docstring


def predefined_class_as_string(
    alias: str, contents: DescMapping, info: PredefinedClass
) -> str:
    lnames = ""
    nonPyIdentifiers: list[str] = list()

    for lname in sorted(contents.keys()):
        comment = contents[lname]
        attr = lname.value.removeprefix(info.nsIRI)
        if not len(attr):
            continue  # ignore the `:` subject
        if not attr.isidentifier() or keyword.iskeyword(attr):
            # we can't add this directly, sadly losing docstrings too...
            nonPyIdentifiers.append(attr)
            continue
        docstring = comment.value
        lnames += f'''
    {attr}: NamedNode
    """{docstring}"""'''

    return f'''\
from pyoxigraph import NamedNode

from pyrdf_prefix import PredefinedNamespace

class {alias}(PredefinedNamespace):
    """{info.title}"""
    # Conversion-Date: {dt.datetime.now(dt.UTC).isoformat(timespec='minutes')}
    # Source: {info.sourceIRI or info.nsIRI}

    _nsBaseIri = "{info.nsIRI}"
    _issueWarning = {info.issueWarnings}
    _withContainerMembershipProperty = {info.hasContainerMembershipProperties}
    _nonPyIdentifiers = {tuple(nonPyIdentifiers)}

    {lnames}
'''


def known_prefixes():
    results: dict[str, PredefinedClass] = dict()
    with open("docs/Predefined-Namespaces.tsv") as tsv:
        reader = csv.DictReader(
            tsv,
            (
                "Prefix",
                "NamespaceIRI",
                "SourceIRI",
                "Title",
                "SourceFormat",
                "ReasonForInclusion",
            ),
            delimiter="\t",
        )
        next(reader)
        for line in reader:
            results[line["Prefix"]] = PredefinedClass(
                line["NamespaceIRI"],
                RdfFormat.from_extension(line["SourceFormat"]),
                issueWarnings=True,
                sourceIRI=line["SourceIRI"],
                hasContainerMembershipProperties=line["Prefix"] == "RDF",
                title=line["Title"],
            )

    return results


if __name__ == "__main__":
    failed = set()
    for alias, info in known_prefixes().items():
        try:
            contents = load_from_url(info)
            result = predefined_class_as_string(alias, contents, info)
            outfn = f"src/pyrdf_prefix/predefined/_{alias}.py"
            with open(outfn, "w") as out:
                print(result, file=out)
            print(f"PredefinedNamespace for '{alias}' DONE: {outfn}")
        except Exception as err:
            print(f"PredefinedNamespace for '{alias}' FAIL:", err, file=stderr)
            failed.add(alias)
            continue

    print(f"FAILED: {', '.join(failed)}")



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class TIME(PredefinedNamespace):
    """OWL-Time"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/2006/time#

    _nsBaseIri = "http://www.w3.org/2006/time#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    DateTimeDescription: NamedNode
    """Description of date and time structured with separate values for the various elements of a calendar-clock system. The temporal reference system is fixed to Gregorian Calendar, and the range of year, month, day properties restricted to corresponding XML Schema types xsd:gYear, xsd:gMonth and xsd:gDay, respectively."""
    DateTimeInterval: NamedNode
    """DateTimeInterval is a subclass of ProperInterval, defined using the multi-element DateTimeDescription."""
    DayOfWeek: NamedNode
    """The day of week"""
    Duration: NamedNode
    """Duration of a temporal extent expressed as a number scaled by a temporal unit"""
    DurationDescription: NamedNode
    """Description of temporal extent structured with separate values for the various elements of a calendar-clock system. The temporal reference system is fixed to Gregorian Calendar, and the range of each of the numeric properties is restricted to xsd:decimal"""
    GeneralDateTimeDescription: NamedNode
    """Descripción de fecha y hora estructurada con valores separados para los distintos elementos de un sistema calendario-reloj."""
    GeneralDurationDescription: NamedNode
    """Description of temporal extent structured with separate values for the various elements of a calendar-clock system."""
    Instant: NamedNode
    """A temporal entity with zero extent or duration"""
    Interval: NamedNode
    """A temporal entity with an extent or duration"""
    MonthOfYear: NamedNode
    """The month of the year"""
    ProperInterval: NamedNode
    """A temporal entity with non-zero extent or duration, i.e. for which the value of the beginning and end are different"""
    TRS: NamedNode
    """A temporal reference system, such as a temporal coordinate system (with an origin, direction, and scale), a calendar-clock combination, or a (possibly hierarchical) ordinal system. 

This is a stub class, representing the set of all temporal reference systems."""
    TemporalDuration: NamedNode
    """Time extent; duration of a time interval separate from its particular start position"""
    TemporalEntity: NamedNode
    """A temporal interval or instant."""
    TemporalPosition: NamedNode
    """A position on a time-line"""
    TemporalUnit: NamedNode
    """A standard duration, which provides a scale factor for a time extent, or the granularity or precision for a time position."""
    TimePosition: NamedNode
    """A temporal position described using either a (nominal) value from an ordinal reference system, or a (numeric) value in a temporal coordinate system. """
    TimeZone: NamedNode
    """A Time Zone specifies the amount by which the local time is offset from UTC. 
	A time zone is usually denoted geographically (e.g. Australian Eastern Daylight Time), with a constant value in a given region. 
The region where it applies and the offset from UTC are specified by a locally recognised governing authority."""
    Year: NamedNode
    """Year duration"""
    after: NamedNode
    """Gives directionality to time. If a temporal entity T1 is after another temporal entity T2, then the beginning of T1 is after the end of T2."""
    before: NamedNode
    """Gives directionality to time. If a temporal entity T1 is before another temporal entity T2, then the end of T1 is before the beginning of T2. Thus, "before" can be considered to be basic to instants and derived for intervals."""
    day: NamedNode
    """Day position in a calendar-clock system.

The range of this property is not specified, so can be replaced by any specific representation of a calendar day from any calendar. """
    dayOfWeek: NamedNode
    """The day of week, whose value is a member of the class time:DayOfWeek"""
    dayOfYear: NamedNode
    """The number of the day within the year"""
    days: NamedNode
    """length of, or element of the length of, a temporal extent expressed in days"""
    generalDay: NamedNode
    """Day of month - formulated as a text string with a pattern constraint to reproduce the same lexical form as gDay, except that values up to 99 are permitted, in order to support calendars with more than 31 days in a month. 
Note that the value-space is not defined, so a generic OWL2 processor cannot compute ordering relationships of values of this type."""
    generalMonth: NamedNode
    """Month of year - formulated as a text string with a pattern constraint to reproduce the same lexical form as gMonth, except that values up to 20 are permitted, in order to support calendars with more than 12 months in the year. 
Note that the value-space is not defined, so a generic OWL2 processor cannot compute ordering relationships of values of this type."""
    generalYear: NamedNode
    """Year number - formulated as a text string with a pattern constraint to reproduce the same lexical form as gYear, but not restricted to values from the Gregorian calendar. 
Note that the value-space is not defined, so a generic OWL2 processor cannot compute ordering relationships of values of this type."""
    hasBeginning: NamedNode
    """Beginning of a temporal entity."""
    hasDateTimeDescription: NamedNode
    """Value of DateTimeInterval expressed as a structured value. The beginning and end of the interval coincide with the limits of the shortest element in the description."""
    hasDuration: NamedNode
    """Duration of a temporal entity, event or activity, or thing, expressed as a scaled value"""
    hasDurationDescription: NamedNode
    """Duration of a temporal entity, expressed using a structured description"""
    hasEnd: NamedNode
    """End of a temporal entity."""
    hasTRS: NamedNode
    """The temporal reference system used by a temporal position or extent description. """
    hasTemporalDuration: NamedNode
    """Duration of a temporal entity."""
    hasTime: NamedNode
    """Supports the association of a temporal entity (instant or interval) to any thing"""
    hasXSDDuration: NamedNode
    """Extent of a temporal entity, expressed using xsd:duration"""
    hour: NamedNode
    """Hour position in a calendar-clock system."""
    hours: NamedNode
    """length of, or element of the length of, a temporal extent expressed in hours"""
    inDateTime: NamedNode
    """Position of an instant, expressed using a structured description"""
    inTemporalPosition: NamedNode
    """Position of a time instant"""
    inTimePosition: NamedNode
    """Position of a time instant expressed as a TimePosition"""
    inXSDDate: NamedNode
    """Position of an instant, expressed using xsd:date"""
    inXSDDateTime: NamedNode
    """Position of an instant, expressed using xsd:dateTime"""
    inXSDDateTimeStamp: NamedNode
    """Position of an instant, expressed using xsd:dateTimeStamp"""
    inXSDgYear: NamedNode
    """Position of an instant, expressed using xsd:gYear"""
    inXSDgYearMonth: NamedNode
    """Position of an instant, expressed using xsd:gYearMonth"""
    inside: NamedNode
    """An instant that falls inside the interval. It is not intended to include beginnings and ends of intervals."""
    intervalAfter: NamedNode
    """If a proper interval T1 is intervalAfter another proper interval T2, then the beginning of T1 is after the end of T2."""
    intervalBefore: NamedNode
    """If a proper interval T1 is intervalBefore another proper interval T2, then the end of T1 is before the beginning of T2."""
    intervalContains: NamedNode
    """If a proper interval T1 is intervalContains another proper interval T2, then the beginning of T1 is before the beginning of T2, and the end of T1 is after the end of T2."""
    intervalDisjoint: NamedNode
    """If a proper interval T1 is intervalDisjoint another proper interval T2, then the beginning of T1 is after the end of T2, or the end of T1 is before the beginning of T2, i.e. the intervals do not overlap in any way, but their ordering relationship is not known."""
    intervalDuring: NamedNode
    """If a proper interval T1 is intervalDuring another proper interval T2, then the beginning of T1 is after the beginning of T2, and the end of T1 is before the end of T2."""
    intervalEquals: NamedNode
    """If a proper interval T1 is intervalEquals another proper interval T2, then the beginning of T1 is coincident with the beginning of T2, and the end of T1 is coincident with the end of T2."""
    intervalFinishedBy: NamedNode
    """If a proper interval T1 is intervalFinishedBy another proper interval T2, then the beginning of T1 is before the beginning of T2, and the end of T1 is coincident with the end of T2."""
    intervalFinishes: NamedNode
    """If a proper interval T1 is intervalFinishes another proper interval T2, then the beginning of T1 is after the beginning of T2, and the end of T1 is coincident with the end of T2."""
    intervalIn: NamedNode
    """If a proper interval T1 is intervalIn another proper interval T2, then the beginning of T1 is after the beginning of T2 or is coincident with the beginning of T2, and the end of T1 is before the end of T2, or is coincident with the end of T2, except that end of T1 may not be coincident with the end of T2 if the beginning of T1 is coincident with the beginning of T2."""
    intervalMeets: NamedNode
    """If a proper interval T1 is intervalMeets another proper interval T2, then the end of T1 is coincident with the beginning of T2."""
    intervalMetBy: NamedNode
    """If a proper interval T1 is intervalMetBy another proper interval T2, then the beginning of T1 is coincident with the end of T2."""
    intervalOverlappedBy: NamedNode
    """If a proper interval T1 is intervalOverlappedBy another proper interval T2, then the beginning of T1 is after the beginning of T2, the beginning of T1 is before the end of T2, and the end of T1 is after the end of T2."""
    intervalOverlaps: NamedNode
    """If a proper interval T1 is intervalOverlaps another proper interval T2, then the beginning of T1 is before the beginning of T2, the end of T1 is after the beginning of T2, and the end of T1 is before the end of T2."""
    intervalStartedBy: NamedNode
    """If a proper interval T1 is intervalStarted another proper interval T2, then the beginning of T1 is coincident with the beginning of T2, and the end of T1 is after the end of T2."""
    intervalStarts: NamedNode
    """If a proper interval T1 is intervalStarts another proper interval T2, then the beginning of T1 is coincident with the beginning of T2, and the end of T1 is before the end of T2."""
    minute: NamedNode
    """Minute position in a calendar-clock system."""
    minutes: NamedNode
    """length, or element of, a temporal extent expressed in minutes"""
    month: NamedNode
    """Month position in a calendar-clock system.

The range of this property is not specified, so can be replaced by any specific representation of a calendar month from any calendar. """
    monthOfYear: NamedNode
    """The month of the year, whose value is a member of the class time:MonthOfYear"""
    months: NamedNode
    """length of, or element of the length of, a temporal extent expressed in months"""
    nominalPosition: NamedNode
    """The (nominal) value indicating temporal position in an ordinal reference system """
    numericDuration: NamedNode
    """Value of a temporal extent expressed as a decimal number scaled by a temporal unit"""
    numericPosition: NamedNode
    """The (numeric) value indicating position within a temporal coordinate system """
    second: NamedNode
    """Second position in a calendar-clock system."""
    seconds: NamedNode
    """length of, or element of the length of, a temporal extent expressed in seconds"""
    timeZone: NamedNode
    """The time zone for clock elements in the temporal position"""
    unitType: NamedNode
    """The temporal unit which provides the precision of a date-time value or scale of a temporal extent"""
    week: NamedNode
    """Week number within the year."""
    weeks: NamedNode
    """length of, or element of the length of, a temporal extent expressed in weeks"""
    xsdDateTime: NamedNode
    """Value of DateTimeInterval expressed as a compact value."""
    year: NamedNode
    """Year position in a calendar-clock system.

The range of this property is not specified, so can be replaced by any specific representation of a calendar year from any calendar. """
    years: NamedNode
    """length of, or element of the length of, a temporal extent expressed in years"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class WDRS(PredefinedNamespace):
    """Protocol for Web Description Resources (POWDER)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/2007/05/powder-s.rdf

    _nsBaseIri = "http://www.w3.org/2007/05/powder-s#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Document: NamedNode
    """A POWDER document."""
    Processor: NamedNode
    """A software agent able to process POWDER documents."""
    authenticate: NamedNode
    """A pointer to a document that describes how Description Resources created by a FOAF Agent or a DC Terms Agent may be authenticated"""
    certified: NamedNode
    """A property that takes a Boolean value to declare whether the author of the data certifies the described resource."""
    certifiedby: NamedNode
    """A property that links a resource to a POWDER document that certifies it."""
    data_error: NamedNode
    """A property denoting a description of the specific error found in a given POWDER document."""
    describedby: NamedNode
    """An RDF property to exactly match the describedby relationship type introduced in http://www.w3.org/TR/powder-dr/#assoc-linking and formally defined in appendix D of the same document, i.e. the relationship A 'describedby' B asserts that resource B provides a description of resource A. There are no constraints on the format or representation of either A or B, neither are there any further constraints on either resource."""
    error_code: NamedNode
    """A property denoting the code of any error encountered by the POWDER processor."""
    hasIRI: NamedNode
    """This property is meant to be used in OWL2 instead of wdrs:matchesregex. It denotes the string data range corresponding to a set of IRIs."""
    issuedby: NamedNode
    """This property denotes the author of a POWDER document."""
    logo: NamedNode
    """Points to a graphic summary for the resources in a given class. Typically, it is a logo denoting conformance of a given (set of) resource(s) to a given set of criteria."""
    matchesregex: NamedNode
    """This is the key 'include' property for IRI set definitions in POWDER-S. It is necessary to take account of the POWDER Semantic Extension to process this fully. The value is a regular expression that is matched against an IRI."""
    notknownto: NamedNode
    """Property used in results returned from a POWDER Processor that has no data about the candidate resource. The value is the IRI of the processor."""
    notmatchesregex: NamedNode
    """This is the key 'exclude' property for IRI set definitions in POWDER-S. It is necessary to take account of the POWDER Semantic Extension to process this fully. The value is a regular expression that is matched against an IRI."""
    proc_error: NamedNode
    """A property denoting a description of the specific software error."""
    sha1sum: NamedNode
    """Links to a Base64-encoded binary SHA-1 hash of the described resource. May be used by POWDER Processors when assessing trustworthiness of a DR."""
    supportedby: NamedNode
    """A property that links a POWDER document to some other data source that supports the descriptions provided."""
    tag: NamedNode
    """Property linking to a free-text tag which may include spaces."""
    text: NamedNode
    """This property provides a summary of the descriptorset that it annotates, suitable for display to end users."""
    validfrom: NamedNode
    """Provides a timestamp that a POWDER Processor may use when assessing trustworthiness of a POWDER document. Informally, a POWDER Processor should normally ignore data in the document before the given date."""
    validuntil: NamedNode
    """Provides a timestamp that a POWDER Processor may use when assessing trustworthiness of a POWDER document. Informally, a POWDER Processor should normally ignore data in the document after the given date."""


DESCRIBEDBY = WDRS.describedby



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DOAP(PredefinedNamespace):
    """Description of a Project (DOAP) vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://usefulinc.com/ns/doap#

    _nsBaseIri = "http://usefulinc.com/ns/doap#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = (
        "anon-root",
        "bug-database",
        "developer-forum",
        "download-mirror",
        "download-page",
        "file-release",
        "mailing-list",
        "old-homepage",
        "programming-language",
        "security-contact",
        "security-policy",
        "service-endpoint",
        "support-forum",
    )

    ArchRepository: NamedNode
    """GNU Arch source code repository."""
    BKRepository: NamedNode
    """BitKeeper source code repository."""
    BazaarBranch: NamedNode
    """Bazaar source code branch."""
    CVSRepository: NamedNode
    """CVS source code repository."""
    DarcsRepository: NamedNode
    """darcs source code repository."""
    GitBranch: NamedNode
    """Git source code branch."""
    GitRepository: NamedNode
    """Git source code repository."""
    HgRepository: NamedNode
    """Mercurial source code repository."""
    Project: NamedNode
    """A project."""
    Repository: NamedNode
    """Source code repository."""
    SVNRepository: NamedNode
    """Subversion source code repository."""
    Specification: NamedNode
    """A specification of a system's aspects, technical or otherwise."""
    Version: NamedNode
    """Version information of a project release."""
    audience: NamedNode
    """Description of target user base"""
    blog: NamedNode
    """URI of a blog related to a project"""
    browse: NamedNode
    """Web browser interface to repository."""
    category: NamedNode
    """A category of project."""
    created: NamedNode
    """Date when something was created, in YYYY-MM-DD form. e.g. 2004-04-05"""
    description: NamedNode
    """Plain text description of a project, of 2-4 sentences in length."""
    developer: NamedNode
    """Developer of software for the project."""
    documentation: NamedNode
    """Documentation of the project."""
    documenter: NamedNode
    """Contributor of documentation to the project."""
    helper: NamedNode
    """Project contributor."""
    homepage: NamedNode
    """URL of a project's homepage,
		associated with exactly one project."""
    implements: NamedNode
    """A specification that a project implements. Could be a standard, API or legally defined level of conformance."""
    language: NamedNode
    """BCP47 language code a project has been translated into"""
    license: NamedNode
    """The URI of an RDF description of the license the software is distributed under. E.g. a SPDX reference"""
    location: NamedNode
    """Location of a repository."""
    maintainer: NamedNode
    """Maintainer of a project, a project leader."""
    module: NamedNode
    """Module name of a Subversion, CVS, BitKeeper or Arch repository."""
    name: NamedNode
    """A name of something."""
    os: NamedNode
    """Operating system that a project is limited to.  Omit this property if the project is not OS-specific."""
    platform: NamedNode
    """Indicator of software platform (non-OS specific), e.g. Java, Firefox, ECMA CLR"""
    release: NamedNode
    """A project release."""
    repository: NamedNode
    """Source code repository."""
    repositoryOf: NamedNode
    """The project that uses a repository."""
    revision: NamedNode
    """Revision identifier of a software release."""
    screenshots: NamedNode
    """Web page with screenshots of project."""
    shortdesc: NamedNode
    """Short (8 or 9 words) plain text description of a project."""
    tester: NamedNode
    """A tester or other quality control contributor."""
    translator: NamedNode
    """Contributor of translations to the project."""
    vendor: NamedNode
    """Vendor organization: commercial, free or otherwise"""
    wiki: NamedNode
    """URL of Wiki for collaborative discussion of project."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class RR(PredefinedNamespace):
    """R2RML: RDB to RDF Mapping Language Schema"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/r2rml.ttl

    _nsBaseIri = "http://www.w3.org/ns/r2rml#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ("class",)

    BlankNode: NamedNode
    """Denotes a blank node, used with termType"""
    GraphMap: NamedNode
    """Represents a graph map."""
    IRI: NamedNode
    """Denotes an IRI, used with termpType."""
    Join: NamedNode
    """Represents a join condition."""
    Literal: NamedNode
    """Denotes a Literal, used with termType."""
    LogicalTable: NamedNode
    """Represents a logical table."""
    ObjectMap: NamedNode
    """Represents an object map."""
    PredicateMap: NamedNode
    """Represents a predicate map."""
    PredicateObjectMap: NamedNode
    """Represents a predicate-object map."""
    RefObjectMap: NamedNode
    """Denotes a reference to an object map."""
    SQL2008: NamedNode
    """Core SQL 2008"""
    SubjectMap: NamedNode
    """Represents a subject map."""
    TermMap: NamedNode
    """A function that generates an RDF term from a logical table row."""
    TriplesMap: NamedNode
    """Represents a triples map."""
    child: NamedNode
    """Names a column in the child table of a join."""
    column: NamedNode
    """Name of a column in the logical table. When generating RDF triples from a logical table row, value from the specified column is used as the subject, predicate, or object (based upon the specific domain)."""
    datatype: NamedNode
    """Specifies the datatype of the object component for the generated triple from a logical table row."""
    defaultGraph: NamedNode
    """Denotes a default graph"""
    graph: NamedNode
    """An IRI reference for use as the graph name of all triples generated with the GraphMap."""
    graphMap: NamedNode
    """Specifies a GraphMap. When used with a SubjectMap element, all the RDF triples generated from a logical row will be stored in the specified named graph. Otherwise, the RDF triple generated using the (predicate, object) pair will be stored in the specified named graph."""
    inverseExpression: NamedNode
    """An expression that allows, at query processing time, use of index-based access to the the (underlying) relational tables, instead of simply retrieving the table rows first and then applying a filter. This property is useful for retrieval based on conditions involving subject, predicate, or object generated from logical table column(s) and involves some transformation."""
    joinCondition: NamedNode
    """Specifies the join condition for joining the child logical table with the parent logical table of the foreign key constraint."""
    language: NamedNode
    """Specified the language for the object component for the generated triple from a logical table row."""
    logicalTable: NamedNode
    """Definition of logical table to be mapped."""
    object: NamedNode
    """Specifies the object for the generated triple from the logical table row."""
    objectMap: NamedNode
    """An ObjectMap element to generate the object component of the (predicate, object) pair from a logical table row."""
    parent: NamedNode
    """Names a column in the parent table of a join."""
    parentTriplesMap: NamedNode
    """Specifies the TriplesMap element corresponding to the parent logical table of the foreign key constraint."""
    predicate: NamedNode
    """Specifies the predicate for the generated triple from the logical table row."""
    predicateMap: NamedNode
    """A PredicateMap element to generate the predicate component of the (predicate, object) pair from a logical table row."""
    predicateObjectMap: NamedNode
    """A PredicateObjectMap element to generate (predicate, object) pair from a logical table row."""
    sqlQuery: NamedNode
    """A valid SQL query."""
    sqlVersion: NamedNode
    """An identifier for a SQL version."""
    subject: NamedNode
    """An IRI reference for use as subject for all the RDF triples generated from a logical table row."""
    subjectMap: NamedNode
    """A SubjectMap element to generate a subject from a logical table row."""
    tableName: NamedNode
    """Schema-qualified name of a table or view."""
    template: NamedNode
    """A template (format string) to specify how to generate a value for a subject, predicate, or object, using one or more columns from a logical table row."""
    termType: NamedNode
    """A string indicating whether subject or object generated using the value from column name specified for rr:column should be an IRI reference, blank node, or a literal."""



from pyrdf_prefix.namespace import PredefinedNamespace


class RDFA(PredefinedNamespace):
    """RDFa Vocabulary for Term and Prefix Assignment"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/rdfa.ttl

    _nsBaseIri = "http://www.w3.org/ns/rdfa#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DCMITYPE(PredefinedNamespace):
    """Dublin Core DCMI Type Vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.dublincore.org/specifications/dublin-core/dcmi-terms/dublin_core_type.nt

    _nsBaseIri = "http://purl.org/dc/dcmitype/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Collection: NamedNode
    """An aggregation of resources."""
    Dataset: NamedNode
    """Data encoded in a defined structure."""
    Event: NamedNode
    """A non-persistent, time-based occurrence."""
    Image: NamedNode
    """A visual representation other than text."""
    InteractiveResource: NamedNode
    """A resource requiring interaction from the user to be understood, executed, or experienced."""
    MovingImage: NamedNode
    """A series of visual representations imparting an impression of motion when shown in succession."""
    PhysicalObject: NamedNode
    """An inanimate, three-dimensional object or substance."""
    Service: NamedNode
    """A system that provides one or more functions."""
    Software: NamedNode
    """A computer program in source or compiled form."""
    Sound: NamedNode
    """A resource primarily intended to be heard."""
    StillImage: NamedNode
    """A static visual representation."""
    Text: NamedNode
    """A resource consisting primarily of words for reading."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class CC(PredefinedNamespace):
    """Creative Commons"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://creativecommons.org/schema.rdf

    _nsBaseIri = "http://creativecommons.org/ns#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Attribution: NamedNode
    """credit be given to copyright holder and/or author"""
    CommercialUse: NamedNode
    """exercising rights for commercial purposes"""
    Copyleft: NamedNode
    """derivative and combined works must be licensed under specified terms, similar to those on the original work"""
    DerivativeWorks: NamedNode
    """distribution of derivative works"""
    Distribution: NamedNode
    """distribution, public display, and publicly performance"""
    HighIncomeNationUse: NamedNode
    """use in a non-developing country"""
    Jurisdiction: NamedNode
    """the legal jurisdiction of a license"""
    LesserCopyleft: NamedNode
    """derivative works must be licensed under specified terms, with at least the same conditions as the original work; combinations with the work may be licensed under different terms"""
    License: NamedNode
    """a set of requests/permissions to users of a Work, e.g. a copyright license, the public domain, information for distributors"""
    Notice: NamedNode
    """copyright and license notices be kept intact"""
    Permission: NamedNode
    """an action that may or may not be allowed or desired"""
    Prohibition: NamedNode
    """something you may be asked not to do"""
    Reproduction: NamedNode
    """making multiple copies"""
    Requirement: NamedNode
    """an action that may or may not be requested of you"""
    ShareAlike: NamedNode
    """derivative works be licensed under the same terms or compatible terms as the original work"""
    Sharing: NamedNode
    """permits commercial derivatives, but only non-commercial distribution"""
    SourceCode: NamedNode
    """source code (the preferred form for making modifications) must be provided when exercising some rights granted by the license."""
    Work: NamedNode
    """a potentially copyrightable work"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DCTERMS(PredefinedNamespace):
    """Dublin Core DCMI Metadata Terms"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.dublincore.org/specifications/dublin-core/dcmi-terms/dublin_core_terms.nt

    _nsBaseIri = "http://purl.org/dc/terms/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ("ISO639-2", "ISO639-3")

    Agent: NamedNode
    """A resource that acts or has the power to act."""
    AgentClass: NamedNode
    """A group of agents."""
    BibliographicResource: NamedNode
    """A book, article, or other documentary resource."""
    Box: NamedNode
    """The set of regions in space defined by their geographic coordinates according to the DCMI Box Encoding Scheme."""
    DCMIType: NamedNode
    """The set of classes specified by the DCMI Type Vocabulary, used to categorize the nature or genre of the resource."""
    DDC: NamedNode
    """The set of conceptual resources specified by the Dewey Decimal Classification."""
    FileFormat: NamedNode
    """A digital resource format."""
    Frequency: NamedNode
    """A rate at which something recurs."""
    IMT: NamedNode
    """The set of media types specified by the Internet Assigned Numbers Authority."""
    ISO3166: NamedNode
    """The set of codes listed in ISO 3166-1 for the representation of names of countries."""
    Jurisdiction: NamedNode
    """The extent or range of judicial, law enforcement, or other authority."""
    LCC: NamedNode
    """The set of conceptual resources specified by the Library of Congress Classification."""
    LCSH: NamedNode
    """The set of labeled concepts specified by the Library of Congress Subject Headings."""
    LicenseDocument: NamedNode
    """A legal document giving official permission to do something with a resource."""
    LinguisticSystem: NamedNode
    """A system of signs, symbols, sounds, gestures, or rules used in communication."""
    Location: NamedNode
    """A spatial region or named place."""
    LocationPeriodOrJurisdiction: NamedNode
    """A location, period of time, or jurisdiction."""
    MESH: NamedNode
    """The set of labeled concepts specified by the Medical Subject Headings."""
    MediaType: NamedNode
    """A file format or physical medium."""
    MediaTypeOrExtent: NamedNode
    """A media type or extent."""
    MethodOfAccrual: NamedNode
    """A method by which resources are added to a collection."""
    MethodOfInstruction: NamedNode
    """A process that is used to engender knowledge, attitudes, and skills."""
    NLM: NamedNode
    """The set of conceptual resources specified by the National Library of Medicine Classification."""
    Period: NamedNode
    """The set of time intervals defined by their limits according to the DCMI Period Encoding Scheme."""
    PeriodOfTime: NamedNode
    """An interval of time that is named or defined by its start and end dates."""
    PhysicalMedium: NamedNode
    """A physical material or carrier."""
    PhysicalResource: NamedNode
    """A material thing."""
    Point: NamedNode
    """The set of points in space defined by their geographic coordinates according to the DCMI Point Encoding Scheme."""
    Policy: NamedNode
    """A plan or course of action by an authority, intended to influence and determine decisions, actions, and other matters."""
    ProvenanceStatement: NamedNode
    """Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation."""
    RFC1766: NamedNode
    """The set of tags, constructed according to RFC 1766, for the identification of languages."""
    RFC3066: NamedNode
    """The set of tags constructed according to RFC 3066 for the identification of languages."""
    RFC4646: NamedNode
    """The set of tags constructed according to RFC 4646 for the identification of languages."""
    RFC5646: NamedNode
    """The set of tags constructed according to RFC 5646 for the identification of languages."""
    RightsStatement: NamedNode
    """A statement about the intellectual property rights (IPR) held in or over a resource, a legal document giving official permission to do something with a resource, or a statement about access rights."""
    SizeOrDuration: NamedNode
    """A dimension or extent, or a time taken to play or execute."""
    Standard: NamedNode
    """A reference point against which other things can be evaluated or compared."""
    TGN: NamedNode
    """The set of places specified by the Getty Thesaurus of Geographic Names."""
    UDC: NamedNode
    """The set of conceptual resources specified by the Universal Decimal Classification."""
    URI: NamedNode
    """The set of identifiers constructed according to the generic syntax for Uniform Resource Identifiers as specified by the Internet Engineering Task Force."""
    W3CDTF: NamedNode
    """The set of dates and times constructed according to the W3C Date and Time Formats Specification."""
    abstract: NamedNode
    """A summary of the resource."""
    accessRights: NamedNode
    """Information about who access the resource or an indication of its security status."""
    accrualMethod: NamedNode
    """The method by which items are added to a collection."""
    accrualPeriodicity: NamedNode
    """The frequency with which items are added to a collection."""
    accrualPolicy: NamedNode
    """The policy governing the addition of items to a collection."""
    alternative: NamedNode
    """An alternative name for the resource."""
    audience: NamedNode
    """A class of agents for whom the resource is intended or useful."""
    available: NamedNode
    """Date that the resource became or will become available."""
    bibliographicCitation: NamedNode
    """A bibliographic reference for the resource."""
    conformsTo: NamedNode
    """An established standard to which the described resource conforms."""
    contributor: NamedNode
    """An entity responsible for making contributions to the resource."""
    coverage: NamedNode
    """The spatial or temporal topic of the resource, spatial applicability of the resource, or jurisdiction under which the resource is relevant."""
    created: NamedNode
    """Date of creation of the resource."""
    creator: NamedNode
    """An entity responsible for making the resource."""
    date: NamedNode
    """A point or period of time associated with an event in the lifecycle of the resource."""
    dateAccepted: NamedNode
    """Date of acceptance of the resource."""
    dateCopyrighted: NamedNode
    """Date of copyright of the resource."""
    dateSubmitted: NamedNode
    """Date of submission of the resource."""
    description: NamedNode
    """An account of the resource."""
    educationLevel: NamedNode
    """A class of agents, defined in terms of progression through an educational or training context, for which the described resource is intended."""
    extent: NamedNode
    """The size or duration of the resource."""
    format: NamedNode
    """The file format, physical medium, or dimensions of the resource."""
    hasFormat: NamedNode
    """A related resource that is substantially the same as the pre-existing described resource, but in another format."""
    hasPart: NamedNode
    """A related resource that is included either physically or logically in the described resource."""
    hasVersion: NamedNode
    """A related resource that is a version, edition, or adaptation of the described resource."""
    identifier: NamedNode
    """An unambiguous reference to the resource within a given context."""
    instructionalMethod: NamedNode
    """A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support."""
    isFormatOf: NamedNode
    """A pre-existing related resource that is substantially the same as the described resource, but in another format."""
    isPartOf: NamedNode
    """A related resource in which the described resource is physically or logically included."""
    isReferencedBy: NamedNode
    """A related resource that references, cites, or otherwise points to the described resource."""
    isReplacedBy: NamedNode
    """A related resource that supplants, displaces, or supersedes the described resource."""
    isRequiredBy: NamedNode
    """A related resource that requires the described resource to support its function, delivery, or coherence."""
    isVersionOf: NamedNode
    """A related resource of which the described resource is a version, edition, or adaptation."""
    issued: NamedNode
    """Date of formal issuance of the resource."""
    language: NamedNode
    """A language of the resource."""
    license: NamedNode
    """A legal document giving official permission to do something with the resource."""
    mediator: NamedNode
    """An entity that mediates access to the resource."""
    medium: NamedNode
    """The material or physical carrier of the resource."""
    modified: NamedNode
    """Date on which the resource was changed."""
    provenance: NamedNode
    """A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation."""
    publisher: NamedNode
    """An entity responsible for making the resource available."""
    references: NamedNode
    """A related resource that is referenced, cited, or otherwise pointed to by the described resource."""
    relation: NamedNode
    """A related resource."""
    replaces: NamedNode
    """A related resource that is supplanted, displaced, or superseded by the described resource."""
    requires: NamedNode
    """A related resource that is required by the described resource to support its function, delivery, or coherence."""
    rights: NamedNode
    """Information about rights held in and over the resource."""
    rightsHolder: NamedNode
    """A person or organization owning or managing rights over the resource."""
    source: NamedNode
    """A related resource from which the described resource is derived."""
    spatial: NamedNode
    """Spatial characteristics of the resource."""
    subject: NamedNode
    """A topic of the resource."""
    tableOfContents: NamedNode
    """A list of subunits of the resource."""
    temporal: NamedNode
    """Temporal characteristics of the resource."""
    title: NamedNode
    """A name given to the resource."""
    type: NamedNode
    """The nature or genre of the resource."""
    valid: NamedNode
    """Date (often a range) of validity of a resource."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class RDFS(PredefinedNamespace):
    """The RDF Schema vocabulary (RDFS)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/2000/01/rdf-schema#

    _nsBaseIri = "http://www.w3.org/2000/01/rdf-schema#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Class: NamedNode
    """The class of classes."""
    Container: NamedNode
    """The class of RDF containers."""
    ContainerMembershipProperty: NamedNode
    """The class of container membership properties, rdf:_1, rdf:_2, ...,
                    all of which are sub-properties of 'member'."""
    Datatype: NamedNode
    """The class of RDF datatypes."""
    Literal: NamedNode
    """The class of literal values, eg. textual strings and integers."""
    Resource: NamedNode
    """The class resource, everything."""
    comment: NamedNode
    """A description of the subject resource."""
    domain: NamedNode
    """A domain of the subject property."""
    isDefinedBy: NamedNode
    """The defininition of the subject resource."""
    label: NamedNode
    """A human-readable name for the subject."""
    member: NamedNode
    """A member of the subject resource."""
    range: NamedNode
    """A range of the subject property."""
    seeAlso: NamedNode
    """Further information about the subject resource."""
    subClassOf: NamedNode
    """The subject is a subclass of a class."""
    subPropertyOf: NamedNode
    """The subject is a subproperty of a property."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class ODRL(PredefinedNamespace):
    """Open Digital Rights Language 2.0"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/odrl/2/ODRL22.ttl

    _nsBaseIri = "http://www.w3.org/ns/odrl/2/"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ("and", "or")

    Action: NamedNode
    """An operation on an Asset."""
    Agreement: NamedNode
    """A Policy that grants the assignee a Rule over an Asset from an assigner."""
    All: NamedNode
    """Specifies that the scope of the relationship is all of the collective individuals within a context."""
    All2ndConnections: NamedNode
    """Specifies that the scope of the relationship is all of the second-level connections to the Party."""
    AllConnections: NamedNode
    """Specifies that the scope of the relationship is all of the first-level connections of the Party."""
    AllGroups: NamedNode
    """Specifies that the scope of the relationship is all of the group connections of the Party."""
    Assertion: NamedNode
    """A Policy that asserts a Rule over an Asset from parties."""
    Asset: NamedNode
    """A resource or a collection of resources that are the subject of a Rule."""
    AssetCollection: NamedNode
    """An Asset that is collection of individual resources"""
    AssetScope: NamedNode
    """Scopes for Asset Scope expressions."""
    ConflictTerm: NamedNode
    """Used to establish strategies to resolve conflicts that arise from the merging of Policies or conflicts between Permissions and Prohibitions in the same Policy."""
    Constraint: NamedNode
    """A boolean expression that refines the semantics of an Action and Party/Asset Collection or declare the conditions applicable to a Rule."""
    Duty: NamedNode
    """The obligation to perform an Action"""
    Group: NamedNode
    """Specifies that the scope of the relationship is the defined group with multiple individual members."""
    Individual: NamedNode
    """Specifies that the scope of the relationship is the single Party individual."""
    LeftOperand: NamedNode
    """Left operand for a constraint expression."""
    LogicalConstraint: NamedNode
    """A logical expression that refines the semantics of an Action and Party/Asset Collection or declare the conditions applicable to a Rule."""
    Offer: NamedNode
    """A Policy that proposes a Rule over an Asset from an assigner."""
    Operator: NamedNode
    """Operator for constraint expression."""
    Party: NamedNode
    """An entity or a collection of entities that undertake Roles in a Rule."""
    PartyCollection: NamedNode
    """A Party that is a group of individual entities"""
    PartyScope: NamedNode
    """Scopes for Party Scope expressions."""
    Permission: NamedNode
    """The ability to perform an Action over an Asset."""
    Policy: NamedNode
    """A non-empty group of Permissions and/or Prohibitions."""
    Privacy: NamedNode
    """A Policy that expresses a Rule over an Asset containing personal information."""
    Prohibition: NamedNode
    """The inability to perform an Action over an Asset."""
    Request: NamedNode
    """A Policy that proposes a Rule over an Asset from an assignee."""
    RightOperand: NamedNode
    """Right operand for constraint expression."""
    Rule: NamedNode
    """An abstract concept that represents the common characteristics of Permissions, Prohibitions, and Duties."""
    Set: NamedNode
    """A Policy that expresses a Rule over an Asset."""
    Ticket: NamedNode
    """A Policy that grants the holder a Rule over an Asset from an assigner."""
    UndefinedTerm: NamedNode
    """Is used to indicate how to support Actions that are not part of any vocabulary or profile in the policy expression system."""
    absolutePosition: NamedNode
    """A point in space or time defined with absolute coordinates for the positioning of the target Asset."""
    absoluteSize: NamedNode
    """Measure(s) of one or two axes for 2D-objects or measure(s) of one to tree axes for 3D-objects of the target Asset."""
    absoluteSpatialPosition: NamedNode
    """The absolute spatial positions of four corners of a rectangle on a 2D-canvas or the eight corners of a cuboid in a 3D-space for the target Asset to fit."""
    absoluteTemporalPosition: NamedNode
    """The absolute temporal positions in a media stream the target Asset has to fit."""
    acceptTracking: NamedNode
    """To accept that the use of the Asset may be tracked."""
    action: NamedNode
    """The operation relating to the Asset for which the Rule is being subjected."""
    adHocShare: NamedNode
    """The act of sharing the asset to parties in close proximity to the owner."""
    aggregate: NamedNode
    """To use the Asset or parts of it as part of a composite collection."""
    andSequence: NamedNode
    """The relation is satisfied when each of the Constraints are satisfied in the order specified."""
    annotate: NamedNode
    """To add explanatory notations/commentaries to the Asset without modifying the Asset in any other way."""
    anonymize: NamedNode
    """To anonymize all or parts of the Asset."""
    append: NamedNode
    """The act of adding to the end of an asset."""
    appendTo: NamedNode
    """The act of appending data to the Asset without modifying the Asset in any other way."""
    archive: NamedNode
    """To store the Asset (in a non-transient form)."""
    assignee: NamedNode
    """The Party is the recipient of the Rule."""
    assigneeOf: NamedNode
    """Identifies an ODRL Policy for which the identified Party undertakes the assignee functional role."""
    assigner: NamedNode
    """The Party is the issuer of the Rule."""
    assignerOf: NamedNode
    """Identifies an ODRL Policy for which the identified Party undertakes the assigner functional role."""
    attachPolicy: NamedNode
    """The act of keeping the policy notice with the asset."""
    attachSource: NamedNode
    """The act of attaching the source of the asset and its derivatives."""
    attribute: NamedNode
    """To attribute the use of the Asset."""
    attributedParty: NamedNode
    """The Party to be attributed."""
    attributingParty: NamedNode
    """The Party who undertakes the attribution."""
    commercialize: NamedNode
    """The act of using the asset in a business environment."""
    compensate: NamedNode
    """To compensate by transfer of some amount of value, if defined, for using or selling the Asset."""
    compensatedParty: NamedNode
    """The Party is the recipient of the compensation."""
    compensatingParty: NamedNode
    """The Party that is the provider of the compensation."""
    concurrentUse: NamedNode
    """To create multiple copies of the Asset that are being concurrently used."""
    conflict: NamedNode
    """The conflict-resolution strategy for a Policy."""
    consentedParty: NamedNode
    """The Party who obtains the consent."""
    consentingParty: NamedNode
    """The Party to obtain consent from."""
    consequence: NamedNode
    """Relates a Duty to another Duty, the latter being a consequence of not fulfilling the former."""
    constraint: NamedNode
    """Constraint applied to a Rule"""
    contractedParty: NamedNode
    """The Party who is being contracted."""
    contractingParty: NamedNode
    """The Party who is offering the contract."""
    copy: NamedNode
    """The act of making an exact reproduction of the asset."""
    core: NamedNode
    """Identifier for the ODRL Core Profile"""
    count: NamedNode
    """Numeric count of executions of the action of the Rule."""
    dataType: NamedNode
    """The datatype of the value of the rightOperand or rightOperandReference of a Constraint."""
    dateTime: NamedNode
    """The date (and optional time and timezone) of exercising the action of the Rule. Right operand value MUST be an xsd:date or xsd:dateTime as defined by [[xmlschema11-2]]."""
    delayPeriod: NamedNode
    """A time delay period prior to exercising the action of the Rule. The point in time triggering this period MAY be defined by another temporal Constraint combined by a Logical Constraint (utilising the odrl:andSequence operand). Right operand value MUST be an xsd:duration as defined by [[xmlschema11-2]]."""
    delete: NamedNode
    """To permanently remove all copies of the Asset after it has been used."""
    deliveryChannel: NamedNode
    """The delivery channel used for exercising the action of the Rule."""
    derive: NamedNode
    """To create a new derivative Asset from this Asset and to edit or modify the derivative."""
    device: NamedNode
    """An identified device used for exercising the action of the Rule."""
    digitize: NamedNode
    """To produce a digital copy of (or otherwise digitize) the Asset from its analogue form."""
    display: NamedNode
    """To create a static and transient rendition of an Asset."""
    distribute: NamedNode
    """To supply the Asset to third-parties."""
    duty: NamedNode
    """Relates an individual Duty to a Permission."""
    elapsedTime: NamedNode
    """A continuous elapsed time period which may be used for exercising of the action of the Rule. Right operand value MUST be an xsd:duration as defined by [[xmlschema11-2]]."""
    ensureExclusivity: NamedNode
    """To ensure that the Rule on the Asset is exclusive."""
    eq: NamedNode
    """Indicating that a given value equals the right operand of the Constraint."""
    event: NamedNode
    """An identified event setting a context for exercising the action of the Rule."""
    execute: NamedNode
    """To run the computer program Asset."""
    export: NamedNode
    """The act of transforming the asset into a new form."""
    extract: NamedNode
    """To extract parts of the Asset and to use it as a new Asset."""
    extractChar: NamedNode
    """The act of extracting (replicating) unchanged characters from the asset."""
    extractPage: NamedNode
    """The act of extracting (replicating) unchanged pages from the asset."""
    extractWord: NamedNode
    """The act of extracting (replicating) unchanged words from the asset."""
    failure: NamedNode
    """Failure is an abstract property that defines the violation (or unmet) relationship between Rules."""
    fileFormat: NamedNode
    """A transformed file format of the target Asset."""
    function: NamedNode
    """Function is an abstract property whose sub-properties define the functional roles which may be fulfilled by a party in relation to a Rule."""
    give: NamedNode
    """To transfer the ownership of the Asset to a third party without compensation and while deleting the original asset."""
    grantUse: NamedNode
    """To grant the use of the Asset to third parties."""
    gt: NamedNode
    """Indicating that a given value is greater than the right operand of the Constraint."""
    gteq: NamedNode
    """Indicating that a given value is greater than or equal to the right operand of the Constraint."""
    hasPart: NamedNode
    """A set-based operator indicating that a given value contains the right operand of the Constraint."""
    hasPolicy: NamedNode
    """Identifies an ODRL Policy for which the identified Asset is the target Asset to all the Rules."""
    ignore: NamedNode
    """The Action is to be ignored and is not part of the policy – and the policy remains valid."""
    implies: NamedNode
    """An Action asserts that another Action is not prohibited to enable its operational semantics."""
    include: NamedNode
    """To include other related assets in the Asset."""
    includedIn: NamedNode
    """An Action transitively asserts that another Action that encompasses its operational semantics."""
    index: NamedNode
    """To record the Asset in an index."""
    industry: NamedNode
    """A defined industry sector setting a context for exercising the action of the Rule."""
    inform: NamedNode
    """To inform that an action has been performed on or in relation to the Asset."""
    informedParty: NamedNode
    """The Party to be informed of all uses."""
    informingParty: NamedNode
    """The Party who provides the inform use data."""
    inheritAllowed: NamedNode
    """Indicates if the Policy entity can be inherited."""
    inheritFrom: NamedNode
    """Relates a (child) policy to another (parent) policy from which terms are inherited."""
    inheritRelation: NamedNode
    """Indentifies the type of inheritance."""
    install: NamedNode
    """To load the computer program Asset onto a storage device which allows operating or running the Asset."""
    invalid: NamedNode
    """The policy is void."""
    isA: NamedNode
    """A set-based operator indicating that a given value is an instance of the right operand of the Constraint."""
    isAllOf: NamedNode
    """A set-based operator indicating that a given value is all of the right operand of the Constraint."""
    isAnyOf: NamedNode
    """A set-based operator indicating that a given value is any of the right operand of the Constraint."""
    isNoneOf: NamedNode
    """A set-based operator indicating that a given value is none of the right operand of the Constraint."""
    isPartOf: NamedNode
    """A set-based operator indicating that a given value is contained by the right operand of the Constraint."""
    language: NamedNode
    """A natural language used by the target Asset."""
    lease: NamedNode
    """The act of making available the asset to a third-party for a fixed period of time with exchange of value."""
    leftOperand: NamedNode
    """The left operand in a constraint expression."""
    lend: NamedNode
    """The act of making available the asset to a third-party for a fixed period of time without exchange of value."""
    license: NamedNode
    """The act of granting the right to use the asset to a third-party."""
    lt: NamedNode
    """Indicating that a given value is less than the right operand of the Constraint."""
    lteq: NamedNode
    """Indicating that a given value is less than or equal to the right operand of the Constraint."""
    media: NamedNode
    """Category of a media asset setting a context for exercising the action of the Rule."""
    meteredTime: NamedNode
    """An accumulated amount of one to many metered time periods which were used for exercising the action of the Rule. Right operand value MUST be an xsd:duration as defined by [[xmlschema11-2]]."""
    modify: NamedNode
    """To change existing content of the Asset. A new asset is not created by this action."""
    move: NamedNode
    """To move the Asset from one digital location to another including deleting the original copy."""
    neq: NamedNode
    """Indicating that a given value is not equal to the right operand of the Constraint."""
    nextPolicy: NamedNode
    """To grant the specified Policy to a third party for their use of the Asset."""
    obligation: NamedNode
    """Relates an individual Duty to a Policy."""
    obtainConsent: NamedNode
    """To obtain verifiable consent to perform the requested action in relation to the Asset."""
    operand: NamedNode
    """Operand is an abstract property for a logical relationship."""
    operator: NamedNode
    """The operator function applied to operands of a Constraint"""
    output: NamedNode
    """The output property specifies the Asset which is created from the output of the Action."""
    partOf: NamedNode
    """Identifies an Asset/PartyCollection that the Asset/Party is a member of."""
    pay: NamedNode
    """The act of paying a financial amount to a party for use of the asset."""
    payAmount: NamedNode
    """The amount of a financial payment. Right operand value MUST be an xsd:decimal. """
    payeeParty: NamedNode
    """The Party is the recipient of the payment."""
    percentage: NamedNode
    """A percentage amount of the target Asset relevant for exercising the action of the Rule. Right operand value MUST be an xsd:decimal from 0 to 100."""
    perm: NamedNode
    """Permissions take preference over prohibitions."""
    permission: NamedNode
    """Relates an individual Permission to a Policy."""
    play: NamedNode
    """To create a sequential and transient rendition of an Asset."""
    policyUsage: NamedNode
    """Indicates the actual datetime the action of the Rule was exercised."""
    present: NamedNode
    """To publicly perform the Asset."""
    preview: NamedNode
    """The act of providing a short preview of the asset."""
    print: NamedNode
    """To create a tangible and permanent rendition of an Asset."""
    product: NamedNode
    """Category of product or service setting a context for exercising the action of the Rule."""
    profile: NamedNode
    """The identifier(s) of an ODRL Profile that the Policy conforms to."""
    prohibit: NamedNode
    """Prohibitions take preference over permissions."""
    prohibition: NamedNode
    """Relates an individual Prohibition to a Policy."""
    proximity: NamedNode
    """An value indicating the closeness or nearness."""
    purpose: NamedNode
    """A defined purpose for exercising the action of the Rule."""
    read: NamedNode
    """To obtain data from the Asset."""
    recipient: NamedNode
    """The party receiving the result/outcome of exercising the action of the Rule."""
    refinement: NamedNode
    """Constraint used to refine the semantics of an Action, or Party/Asset Collection"""
    relation: NamedNode
    """Relation is an abstract property which creates an explicit link between an Action and an Asset."""
    relativePosition: NamedNode
    """A point in space or time defined with coordinates relative to full measures the positioning of the target Asset."""
    relativeSize: NamedNode
    """Measure(s) of one or two axes for 2D-objects or measure(s) of one to tree axes for 3D-objects - expressed as percentages of full values - of the target Asset."""
    relativeSpatialPosition: NamedNode
    """The relative spatial positions - expressed as percentages of full values - of four corners of a rectangle on a 2D-canvas or the eight corners of a cuboid in a 3D-space of the target Asset."""
    relativeTemporalPosition: NamedNode
    """A point in space or time defined with coordinates relative to full measures the positioning of the target Asset."""
    remedy: NamedNode
    """Relates an individual remedy Duty to a Prohibition."""
    reproduce: NamedNode
    """To make duplicate copies the Asset in any material form."""
    resolution: NamedNode
    """Resolution of the rendition of the target Asset."""
    reviewPolicy: NamedNode
    """To review the Policy applicable to the Asset."""
    rightOperand: NamedNode
    """The value of the right operand in a constraint expression."""
    rightOperandReference: NamedNode
    """A reference to a web resource providing the value for the right operand of a Constraint."""
    scope: NamedNode
    """The identifier of a scope that provides context to the extent of the entity."""
    secondaryUse: NamedNode
    """The act of using the asset for a purpose other than the purpose it was intended for."""
    sell: NamedNode
    """To transfer the ownership of the Asset to a third party with compensation and while deleting the original asset."""
    share: NamedNode
    """The act of the non-commercial reproduction and distribution of the asset to third-parties."""
    shareAlike: NamedNode
    """The act of distributing any derivative asset under the same terms as the original asset."""
    source: NamedNode
    """Reference to a Asset/PartyCollection"""
    spatial: NamedNode
    """A named and identified geospatial area with defined borders which is used for exercising the action of the Rule. An IRI MUST be used to represent this value."""
    spatialCoordinates: NamedNode
    """A set of coordinates setting the borders of a geospatial area used for exercising the action of the Rule. The coordinates MUST include longitude and latitude, they MAY include altitude and the geodetic datum."""
    status: NamedNode
    """the value generated from the leftOperand action or a value related to the leftOperand set as the reference for the comparison."""
    stream: NamedNode
    """To deliver the Asset in real-time."""
    support: NamedNode
    """The Action is to be supported as part of the policy – and the policy remains valid."""
    synchronize: NamedNode
    """To use the Asset in timed relations with media (audio/visual) elements of another Asset."""
    system: NamedNode
    """An identified computing system used for exercising the action of the Rule."""
    systemDevice: NamedNode
    """An identified computing system or computing device used for exercising the action of the Rule."""
    target: NamedNode
    """The target property indicates the Asset that is the primary subject to which the Rule action directly applies."""
    textToSpeech: NamedNode
    """To have a text Asset read out loud."""
    timeInterval: NamedNode
    """A recurring period of time before the next execution of the action of the Rule. Right operand value MUST be an xsd:duration as defined by [[xmlschema11-2]]."""
    timedCount: NamedNode
    """The number of seconds after which timed metering use of the asset begins."""
    trackedParty: NamedNode
    """The Party whose usage is being tracked."""
    trackingParty: NamedNode
    """The Party who is tracking usage."""
    transfer: NamedNode
    """To transfer the ownership of the Asset in perpetuity."""
    transform: NamedNode
    """To convert the Asset into a different format."""
    translate: NamedNode
    """To translate the original natural language of an Asset into another natural language."""
    uid: NamedNode
    """An unambiguous identifier"""
    undefined: NamedNode
    """Relates the strategy used for handling undefined actions to a Policy."""
    uninstall: NamedNode
    """To unload and delete the computer program Asset from a storage device and disable its readiness for operation."""
    unit: NamedNode
    """The unit of measurement of the value of the rightOperand or rightOperandReference of a Constraint."""
    unitOfCount: NamedNode
    """The unit of measure used for counting the executions of the action of the Rule."""
    use: NamedNode
    """To use the Asset"""
    version: NamedNode
    """The version of the target Asset."""
    virtualLocation: NamedNode
    """An identified location of the IT communication space which is relevant for exercising the action of the Rule."""
    watermark: NamedNode
    """To apply a watermark to the Asset."""
    write: NamedNode
    """The act of writing to the Asset."""
    writeTo: NamedNode
    """The act of adding data to the Asset."""
    xone: NamedNode
    """The relation is satisfied when only one, and not more, of the Constaints is satisfied"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class DCAT(PredefinedNamespace):
    """Data catalog vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/ns/dcat2.ttl

    _nsBaseIri = "http://www.w3.org/ns/dcat#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Catalog: NamedNode
    """A curated collection of metadata about resources (e.g., datasets and data services in the context of a data catalog)."""
    CatalogRecord: NamedNode
    """A record in a data catalog, describing the registration of a single dataset or data service."""
    DataService: NamedNode
    """A site or end-point providing operations related to the discovery of, access to, or processing functions on, data or related resources."""
    Dataset: NamedNode
    """A collection of data, published or curated by a single source, and available for access or download in one or more represenations."""
    Distribution: NamedNode
    """A specific representation of a dataset. A dataset might be available in multiple serializations that may differ in various ways, including natural language, media-type or format, schematic organization, temporal and spatial resolution, level of detail or profiles (which might specify any or all of the above)."""
    Relationship: NamedNode
    """An association class for attaching additional information to a relationship between DCAT Resources."""
    Resource: NamedNode
    """Resource published or curated by a single agent."""
    Role: NamedNode
    """A role is the function of a resource or agent with respect to another resource, in the context of resource attribution or resource relationships."""
    accessService: NamedNode
    """A site or end-point that gives access to the distribution of the dataset."""
    accessURL: NamedNode
    """A URL of a resource that gives access to a distribution of the dataset. E.g. landing page, feed, SPARQL endpoint. Use for all cases except a simple download link, in which case downloadURL is preferred."""
    bbox: NamedNode
    """The geographic bounding box of a resource."""
    byteSize: NamedNode
    """The size of a distribution in bytes."""
    catalog: NamedNode
    """A catalog whose contents are of interest in the context of this catalog."""
    centroid: NamedNode
    """The geographic center (centroid) of a resource."""
    compressFormat: NamedNode
    """The compression format of the distribution in which the data is contained in a compressed form, e.g. to reduce the size of the downloadable file."""
    contactPoint: NamedNode
    """Relevant contact information for the catalogued resource. Use of vCard is recommended."""
    dataset: NamedNode
    """A collection of data that is listed in the catalog."""
    distribution: NamedNode
    """An available distribution of the dataset."""
    downloadURL: NamedNode
    """The URL of the downloadable file in a given format. E.g. CSV file or RDF file. The format is indicated by the distribution's dct:format and/or dcat:mediaType."""
    endDate: NamedNode
    """The end of the period."""
    endpointDescription: NamedNode
    """A description of the service end-point, including its operations, parameters etc."""
    endpointURL: NamedNode
    """The root location or primary endpoint of the service (a web-resolvable IRI)."""
    hadRole: NamedNode
    """The function of an entity or agent with respect to another entity or resource."""
    keyword: NamedNode
    """A keyword or tag describing a resource."""
    landingPage: NamedNode
    """A Web page that can be navigated to in a Web browser to gain access to the catalog, a dataset, its distributions and/or additional information."""
    mediaType: NamedNode
    """The media type of the distribution as defined by IANA."""
    packageFormat: NamedNode
    """The package format of the distribution in which one or more data files are grouped together, e.g. to enable a set of related files to be downloaded together."""
    qualifiedRelation: NamedNode
    """Link to a description of a relationship with another resource."""
    record: NamedNode
    """A record describing the registration of a single dataset or data service that is part of the catalog."""
    servesDataset: NamedNode
    """A collection of data that this DataService can distribute."""
    service: NamedNode
    """A site or endpoint that is listed in the catalog."""
    spatialResolutionInMeters: NamedNode
    """minimum spatial separation resolvable in a dataset, measured in meters."""
    startDate: NamedNode
    """The start of the period"""
    temporalResolution: NamedNode
    """minimum time period resolvable in a dataset."""
    theme: NamedNode
    """A main category of the resource. A resource can have multiple themes."""
    themeTaxonomy: NamedNode
    """The knowledge organization system (KOS) used to classify catalog's datasets."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class RDF(PredefinedNamespace):
    """The RDF Concepts Vocabulary (RDF)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/1999/02/22-rdf-syntax-ns#

    _nsBaseIri = "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    _issueWarning = True
    _withContainerMembershipProperty = True
    _nonPyIdentifiers = ()

    Alt: NamedNode
    """The class of containers of alternatives."""
    Bag: NamedNode
    """The class of unordered containers."""
    CompoundLiteral: NamedNode
    """A class representing a compound literal."""
    HTML: NamedNode
    """The datatype of RDF literals storing fragments of HTML content"""
    JSON: NamedNode
    """The datatype of RDF literals storing JSON content."""
    List: NamedNode
    """The class of RDF Lists."""
    PlainLiteral: NamedNode
    """The class of plain (i.e. untyped) literal values, as used in RIF and OWL 2"""
    Property: NamedNode
    """The class of RDF properties."""
    Seq: NamedNode
    """The class of ordered containers."""
    Statement: NamedNode
    """The class of RDF statements."""
    XMLLiteral: NamedNode
    """The datatype of XML literal values."""
    direction: NamedNode
    """The base direction component of a CompoundLiteral."""
    first: NamedNode
    """The first item in the subject RDF list."""
    langString: NamedNode
    """The datatype of language-tagged string values"""
    language: NamedNode
    """The language component of a CompoundLiteral."""
    nil: NamedNode
    """The empty list, with no items in it. If the rest of a list is nil then the list has no more items in it."""
    object: NamedNode
    """The object of the subject RDF statement."""
    predicate: NamedNode
    """The predicate of the subject RDF statement."""
    rest: NamedNode
    """The rest of the subject RDF list after the first item."""
    subject: NamedNode
    """The subject of the subject RDF statement."""
    type: NamedNode
    """The subject is an instance of a class."""
    value: NamedNode
    """Idiomatic property used for structured values."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class GRDDL(PredefinedNamespace):
    """Gleaning resource descriptions from dialects of languages (defunct?)"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://www.w3.org/2003/g/data-view.rdf

    _nsBaseIri = "http://www.w3.org/2003/g/data-view#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    InformationResource: NamedNode
    """A resource which has the property that all of its essential characteristics can be conveyed in a message"""
    RDFGraph: NamedNode
    """a
    set of RDF triples"""
    RootNode: NamedNode
    """the root of the tree in the XPath data
    model"""
    Transformation: NamedNode
    """an InformationResource that specifies
    a transformation from a set of XML documents to RDF graphs"""
    TransformationProperty: NamedNode
    """a FunctionalProperty that relates
    XML document root nodes to
    RDF graphs"""
    namespaceTransformation: NamedNode
    """relates a namespace to a transformation for
    all documents in that namespace"""
    profileTransformation: NamedNode
    """relates a profile document to a
    transformation for all documents bearing that profile"""
    result: NamedNode
    """an
    RDF graph obtained from an information resource by directly
    parsing a representation in the standard RDF/XML syntax or
    indirectly by parsing some other dialect using a transformation
    nominated by the document"""
    transformation: NamedNode
    """relates a source document to a
    transformation, usually represented in XSLT, that relates the source document syntax
    to the RDF graph syntax"""
    transformationProperty: NamedNode
    """relates a transformation to the algorithm
    specified by the property that computes an RDF graph from an XML
    document node"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class OG(PredefinedNamespace):
    """The Open Graph protocol"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: https://ogp.me/ns/ogp.me.ttl

    _nsBaseIri = "http://ogp.me/ns#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = (
        "audio:album",
        "audio:artist",
        "audio:secure_url",
        "audio:title",
        "audio:type",
        "country-name",
        "image:height",
        "image:secure_url",
        "image:type",
        "image:width",
        "postal-code",
        "street-address",
        "video:height",
        "video:secure_url",
        "video:type",
        "video:width",
    )

    audio: NamedNode
    """A relevant audio URL for your object."""
    description: NamedNode
    """A one to two sentence description of your object."""
    determiner: NamedNode
    """The word to precede the object's title in a sentence (e.g., "the" in "the statue of liberty").  Valid values are "a", "an", "the", "", and "auto"."""
    email: NamedNode
    """[DEPRECATED] Email of the contact for your object."""
    fax_number: NamedNode
    """[DEPRECATED] Fax number of the contact for your object."""
    image: NamedNode
    """An image URL which should represent your object within the graph."""
    isbn: NamedNode
    """[DEPRECATED] International Standard Book Number for you object."""
    latitude: NamedNode
    """[DEPRECATED] The latitude of the resource e.g., the latitude of a company."""
    locale: NamedNode
    """A Unix locale in which this markup is rendered."""
    locality: NamedNode
    """[DEPRECATED] The locality of the resource e.g, "Palo Alto"""
    longitude: NamedNode
    """[DEPRECATED] The longitude of the resource e.g., the longitude of a company."""
    phone_number: NamedNode
    """[DEPRECATED] Phone number of the contact for your object."""
    region: NamedNode
    """[DEPRECATED] The region of the resource e.g., "CA"""
    site_name: NamedNode
    """If your object is part of a larger web site, the name which should be displayed for the overall site. e.g., "IMDb"."""
    title: NamedNode
    """The title of the object as it should appear within the graph, e.g.,  "The Rock"."""
    type: NamedNode
    """The type of your object, e.g., "movie".  Depending on the type you specify, other properties may also be required."""
    upc: NamedNode
    """[DEPRECATED] Universal Product Code for your object."""
    url: NamedNode
    """The canonical URL of your object that will be used as its permanent ID in the graph, e.g., "http://www.imdb.com/title/tt0117500/"."""
    video: NamedNode
    """A relevant video URL for your object."""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class QB(PredefinedNamespace):
    """The data cube vocabulary"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://purl.org/linked-data/cube#

    _nsBaseIri = "http://purl.org/linked-data/cube#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Attachable: NamedNode
    """Abstract superclass for everything that can have attributes and dimensions"""
    AttributeProperty: NamedNode
    """The class of components which represent attributes of observations in the cube, e.g. unit of measurement"""
    CodedProperty: NamedNode
    """Superclass of all coded ComponentProperties"""
    ComponentProperty: NamedNode
    """Abstract super-property of all properties representing dimensions, attributes or measures"""
    ComponentSet: NamedNode
    """Abstract class of things which reference one or more ComponentProperties"""
    ComponentSpecification: NamedNode
    """Used to define properties of a component (attribute, dimension etc) which are specific to its usage in a DSD."""
    DataSet: NamedNode
    """Represents a collection of observations, possibly organized into various slices, conforming to some common dimensional structure."""
    DataStructureDefinition: NamedNode
    """Defines the structure of a DataSet or slice"""
    DimensionProperty: NamedNode
    """The class of components which represent the dimensions of the cube"""
    HierarchicalCodeList: NamedNode
    """Represents a generalized hierarchy of concepts which can be used for coding. The hierarchy is defined by one or more roots together with a property which relates concepts in the hierarchy to thier child concept .  The same concepts may be members of multiple hierarchies provided that different qb:parentChildProperty values are used for each hierarchy."""
    MeasureProperty: NamedNode
    """The class of components which represent the measured value of the phenomenon being observed"""
    Observation: NamedNode
    """A single observation in the cube, may have one or more associated measured values"""
    ObservationGroup: NamedNode
    """A, possibly arbitrary, group of observations."""
    Slice: NamedNode
    """Denotes a subset of a DataSet defined by fixing a subset of the dimensional values, component properties on the Slice"""
    SliceKey: NamedNode
    """Denotes a subset of the component properties of a DataSet which are fixed in the corresponding slices"""
    attribute: NamedNode
    """An alternative to qb:componentProperty which makes explicit that the component is a attribute"""
    codeList: NamedNode
    """gives the code list associated with a CodedProperty"""
    component: NamedNode
    """indicates a component specification which is included in the structure of the dataset"""
    componentAttachment: NamedNode
    """Indicates the level at which the component property should be attached, this might an qb:DataSet, qb:Slice or qb:Observation, or a qb:MeasureProperty."""
    componentProperty: NamedNode
    """indicates a ComponentProperty (i.e. attribute/dimension) expected on a DataSet, or a dimension fixed in a SliceKey"""
    componentRequired: NamedNode
    """Indicates whether a component property is required (true) or optional (false) in the context of a DSD. Only applicable
    to components correspond to an attribute. Defaults to false (optional)."""
    concept: NamedNode
    """gives the concept which is being measured or indicated by a ComponentProperty"""
    dataSet: NamedNode
    """indicates the data set of which this observation is a part"""
    dimension: NamedNode
    """An alternative to qb:componentProperty which makes explicit that the component is a dimension"""
    hierarchyRoot: NamedNode
    """Specifies a root of the hierarchy. A hierarchy may have multiple roots but must have at least one."""
    measure: NamedNode
    """An alternative to qb:componentProperty which makes explicit that the component is a measure"""
    measureDimension: NamedNode
    """An alternative to qb:componentProperty which makes explicit that the component is a measure dimension"""
    measureType: NamedNode
    """Generic measure dimension, the value of this dimension indicates which measure (from the set of measures in the DSD) is being given by the obsValue (or other primary measure)"""
    observation: NamedNode
    """indicates a observation contained within this slice of the data set"""
    observationGroup: NamedNode
    """Indicates a group of observations. The domain of this property is left open so that a group may be attached to different resources and need not be restricted to a single DataSet"""
    order: NamedNode
    """indicates a priority order for the components of sets with this structure, used to guide presentations - lower order numbers come before higher numbers, un-numbered components come last"""
    parentChildProperty: NamedNode
    """Specifies a property which relates a parent concept in the hierarchy to a child concept."""
    slice: NamedNode
    """Indicates a subset of a DataSet defined by fixing a subset of the dimensional values"""
    sliceKey: NamedNode
    """indicates a slice key which is used for slices in this dataset"""
    sliceStructure: NamedNode
    """indicates the sub-key corresponding to this slice"""
    structure: NamedNode
    """indicates the structure to which this data set conforms"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class VCARD(PredefinedNamespace):
    """Ontology for vCard based on RFC6350"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.w3.org/2006/vcard/ns#

    _nsBaseIri = "http://www.w3.org/2006/vcard/ns#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = (
        "additional-name",
        "class",
        "country-name",
        "extended-address",
        "family-name",
        "given-name",
        "honorific-prefix",
        "honorific-suffix",
        "organization-name",
        "organization-unit",
        "post-office-box",
        "postal-code",
        "sort-string",
        "street-address",
    )

    Address: NamedNode
    """To specify the components of the delivery address for the  object"""
    BBS: NamedNode
    """This class is deprecated"""
    Car: NamedNode
    """This class is deprecated"""
    Cell: NamedNode
    """Also called mobile telephone"""
    Dom: NamedNode
    """This class is deprecated"""
    Email: NamedNode
    """To specify the electronic mail address for communication with the object the vCard represents. Use the hasEmail object property."""
    Gender: NamedNode
    """Used for gender codes. The URI of the gender code must be used as the value for Gender."""
    Group: NamedNode
    """Object representing a group of persons or entities.  A group object will usually contain hasMember properties to specify the members of the group."""
    Home: NamedNode
    """This implies that the property is related to an individual's personal life"""
    ISDN: NamedNode
    """This class is deprecated"""
    Individual: NamedNode
    """An object representing a single person or entity"""
    Internet: NamedNode
    """This class is deprecated"""
    Intl: NamedNode
    """This class is deprecated"""
    Kind: NamedNode
    """The parent class for all objects"""
    Label: NamedNode
    """This class is deprecated"""
    Location: NamedNode
    """An object representing a named geographical place"""
    Modem: NamedNode
    """This class is deprecated"""
    Msg: NamedNode
    """This class is deprecated"""
    Name: NamedNode
    """To specify the components of the name of the object"""
    Organization: NamedNode
    """An object representing an organization.  An organization is a single entity, and might represent a business or government, a department or division within a business or government, a club, an association, or the like.
"""
    PCS: NamedNode
    """This class is deprecated"""
    Parcel: NamedNode
    """This class is deprecated"""
    Postal: NamedNode
    """This class is deprecated"""
    Pref: NamedNode
    """This class is deprecated"""
    RelatedType: NamedNode
    """Used for relation type codes. The URI of the relation type code must be used as the value for the Relation Type."""
    Tel: NamedNode
    """This class is deprecated. Use the hasTelephone object property."""
    TelephoneType: NamedNode
    """Used for telephone type codes. The URI of the telephone type code must be used as the value for the Telephone Type."""
    Text: NamedNode
    """Also called sms telephone"""
    Type: NamedNode
    """Used for type codes. The URI of the type code must be used as the value for Type."""
    VCard: NamedNode
    """The vCard class is  equivalent to the new Kind class, which is the parent for the four explicit types of vCards (Individual, Organization, Location, Group)"""
    Work: NamedNode
    """This implies that the property is related to an individual's work place"""
    X400: NamedNode
    """This class is deprecated"""
    adr: NamedNode
    """This object property has been mapped"""
    agent: NamedNode
    """This object property has been deprecated"""
    anniversary: NamedNode
    """The date of marriage, or equivalent, of the object"""
    bday: NamedNode
    """To specify the birth date of the object"""
    category: NamedNode
    """The category information about the object, also known as tags"""
    email: NamedNode
    """This object property has been mapped"""
    fn: NamedNode
    """The formatted text corresponding to the name of the object"""
    geo: NamedNode
    """This object property has been mapped"""
    hasAdditionalName: NamedNode
    """Used to support property parameters for the additional name data property"""
    hasAddress: NamedNode
    """To specify the components of the delivery address for the object"""
    hasCalendarBusy: NamedNode
    """To specify the busy time associated with the object. (Was called FBURL in RFC6350)"""
    hasCalendarLink: NamedNode
    """To specify the calendar associated with the object. (Was called CALURI in RFC6350)"""
    hasCalendarRequest: NamedNode
    """To specify the calendar user address to which a scheduling request be sent for the object. (Was called CALADRURI in RFC6350)"""
    hasCategory: NamedNode
    """Used to support property parameters for the category data property"""
    hasCountryName: NamedNode
    """Used to support property parameters for the country name data property"""
    hasEmail: NamedNode
    """To specify the electronic mail address for communication with the object"""
    hasFN: NamedNode
    """Used to support property parameters for the formatted name data property"""
    hasFamilyName: NamedNode
    """Used to support property parameters for the family name data property"""
    hasGender: NamedNode
    """To specify  the sex or gender identity of the object. URIs are recommended to enable interoperable sex and gender codes to be used."""
    hasGeo: NamedNode
    """To specify information related to the global positioning of the object. May also be used as a property parameter."""
    hasGivenName: NamedNode
    """Used to support property parameters for the given name data property"""
    hasHonorificPrefix: NamedNode
    """Used to support property parameters for the honorific prefix data property"""
    hasHonorificSuffix: NamedNode
    """Used to support property parameters for the honorific suffix data property"""
    hasInstantMessage: NamedNode
    """To specify the instant messaging and presence protocol communications with the object. (Was called IMPP in RFC6350)"""
    hasKey: NamedNode
    """To specify a public key or authentication certificate associated with the object"""
    hasLanguage: NamedNode
    """Used to support property parameters for the language data property"""
    hasLocality: NamedNode
    """Used to support property parameters for the locality data property"""
    hasLogo: NamedNode
    """To specify a graphic image of a logo associated with the object """
    hasMember: NamedNode
    """To include a member in the group this object represents. (This property can only be used by Group individuals)"""
    hasName: NamedNode
    """To specify the components of the name of the object"""
    hasNickname: NamedNode
    """Used to support property parameters for the nickname data property"""
    hasNote: NamedNode
    """Used to support property parameters for the note data property"""
    hasOrganizationName: NamedNode
    """Used to support property parameters for the organization name data property"""
    hasOrganizationUnit: NamedNode
    """Used to support property parameters for the organization unit name data property"""
    hasPhoto: NamedNode
    """To specify an image or photograph information that annotates some aspect of the object"""
    hasPostalCode: NamedNode
    """Used to support property parameters for the postal code data property"""
    hasRegion: NamedNode
    """Used to support property parameters for the region data property"""
    hasRelated: NamedNode
    """To specify a relationship between another entity and the entity represented by this object"""
    hasRole: NamedNode
    """Used to support property parameters for the role data property"""
    hasSound: NamedNode
    """To specify a digital sound content information that annotates some aspect of the object"""
    hasSource: NamedNode
    """To identify the source of directory information of the object"""
    hasStreetAddress: NamedNode
    """Used to support property parameters for the street address data property"""
    hasTelephone: NamedNode
    """To specify the telephone number for telephony communication with the object"""
    hasTitle: NamedNode
    """Used to support property parameters for the title data property"""
    hasUID: NamedNode
    """To specify a value that represents a globally unique identifier corresponding to the object"""
    hasURL: NamedNode
    """To specify a uniform resource locator associated with the object"""
    hasValue: NamedNode
    """Used to indicate the resource value of an object property that requires property parameters"""
    key: NamedNode
    """This object property has been mapped"""
    label: NamedNode
    """This data property has been deprecated"""
    language: NamedNode
    """To specify the language that may be used for contacting the object. May also be used as a property parameter."""
    latitude: NamedNode
    """This data property has been deprecated. See hasGeo"""
    locality: NamedNode
    """The locality (e.g. city or town) associated with the address of the object"""
    logo: NamedNode
    """This object property has been mapped"""
    longitude: NamedNode
    """This data property has been deprecated. See hasGeo"""
    mailer: NamedNode
    """This data property has been deprecated"""
    n: NamedNode
    """This object property has been mapped"""
    nickname: NamedNode
    """The nick name associated with the object"""
    note: NamedNode
    """A note associated with the object"""
    org: NamedNode
    """This object property has been mapped. Use the organization-name data property."""
    photo: NamedNode
    """This object property has been mapped"""
    prodid: NamedNode
    """To specify the identifier for the product that created the object"""
    region: NamedNode
    """The region (e.g. state or province) associated with the address of the object"""
    rev: NamedNode
    """To specify revision information about the object"""
    role: NamedNode
    """To specify the function or part played in a particular situation by the object"""
    sound: NamedNode
    """This object property has been mapped"""
    tel: NamedNode
    """This object property has been mapped"""
    title: NamedNode
    """To specify the position or job of the object"""
    tz: NamedNode
    """To indicate time zone information that is specific to the object. May also be used as a property parameter."""
    url: NamedNode
    """This object property has been mapped"""
    value: NamedNode
    """Used to indicate the literal value of a data property that requires property parameters"""



from pyoxigraph import NamedNode

from pyrdf_prefix.namespace import PredefinedNamespace


class GEO(PredefinedNamespace):
    """GeoSPARQL Ontology"""

    # Conversion-Date: 2024-09-30T10:48+00:00
    # Source: http://www.opengis.net/ont/geosparql#

    _nsBaseIri = "http://www.opengis.net/ont/geosparql#"
    _issueWarning = True
    _withContainerMembershipProperty = False
    _nonPyIdentifiers = ()

    Feature: NamedNode
    """A discrete spatial phenomenon in a universe of discourse."""
    FeatureCollection: NamedNode
    """A collection of individual Features."""
    Geometry: NamedNode
    """A coherent set of direct positions in space. The positions are held within a Spatial Reference System (SRS)."""
    GeometryCollection: NamedNode
    """A collection of individual Geometries."""
    SpatialObject: NamedNode
    """Anything spatial (being or having a shape, position or an extent)."""
    SpatialObjectCollection: NamedNode
    """A collection of individual Spatial Objects."""
    asDGGS: NamedNode
    """The Discrete Global Grid System (DGGS) serialization of a Geometry"""
    asGML: NamedNode
    """The GML serialization of a Geometry"""
    asGeoJSON: NamedNode
    """The GeoJSON serialization of a Geometry"""
    asKML: NamedNode
    """The KML serialization of a Geometry"""
    asWKT: NamedNode
    """The WKT serialization of a Geometry"""
    coordinateDimension: NamedNode
    """The number of measurements or axes needed to describe the position of this Geometry in a coordinate system."""
    defaultGeometry: NamedNode
    """The default Geometry to be used in spatial calculations. It is usually the most detailed Geometry."""
    dggsLiteral: NamedNode
    """A textual serialization of a Discrete Global Grid (DGGS) Geometry object."""
    dimension: NamedNode
    """The topological dimension of this geometric object, which must be less than or equal to the coordinate dimension. In non-homogeneous collections, this will return the largest topological dimension of the contained objects."""
    ehContains: NamedNode
    """States that the subject SpatialObject spatially contains the object SpatialObject. DE-9IM: T*TFF*FF*"""
    ehCoveredBy: NamedNode
    """States that the subject SpatialObject is spatially covered by the object SpatialObject. DE-9IM: TFF*TFT**"""
    ehCovers: NamedNode
    """States that the subject SpatialObject spatially covers the object SpatialObject. DE-9IM: T*TFT*FF*"""
    ehDisjoint: NamedNode
    """States that the subject SpatialObject is spatially disjoint from the object SpatialObject. DE-9IM: FF*FF****"""
    ehEquals: NamedNode
    """States that the subject SpatialObject spatially equals the object SpatialObject. DE-9IM: TFFFTFFFT"""
    ehInside: NamedNode
    """States that the subject SpatialObject is spatially inside the object SpatialObject. DE-9IM: TFF*FFT**"""
    ehMeet: NamedNode
    """States that the subject SpatialObject spatially meets the object SpatialObject. DE-9IM: FT******* ^ F**T***** ^ F***T****"""
    ehOverlap: NamedNode
    """States that the subject SpatialObject spatially overlaps the object SpatialObject. DE-9IM: T*T***T**"""
    geoJSONLiteral: NamedNode
    """A GeoJSON serialization of a Geometry object."""
    gmlLiteral: NamedNode
    """A GML serialization of a Geometry object."""
    hasArea: NamedNode
    """The area of a Spatial Object."""
    hasBoundingBox: NamedNode
    """The minimum or smallest bounding or enclosing box of a given Feature."""
    hasCentroid: NamedNode
    """The arithmetic mean position of all the Geometry points of a given Feature."""
    hasDefaultGeometry: NamedNode
    """The default Geometry to be used in spatial calculations. It is usually the most detailed Geometry."""
    hasGeometry: NamedNode
    """A spatial representation for a given Feature."""
    hasLength: NamedNode
    """The length of a Spatial Object."""
    hasMetricArea: NamedNode
    """The area of a Spatial Object in square meters."""
    hasMetricLength: NamedNode
    """The length of a Spatial Object in meters."""
    hasMetricPerimeterLength: NamedNode
    """The length of the perimeter of a Spatial Object in meters."""
    hasMetricSize: NamedNode
    """Subproperties of this property are used to indicate the size of a Spatial Object, as a measurement or estimate of one or more dimensions of the Spatial Object's spatial presence. Units are always metric (meter, square meter or cubic meter)."""
    hasMetricSpatialAccuracy: NamedNode
    """The positional accuracy of the coordinates of a Geometry in meters."""
    hasMetricSpatialResolution: NamedNode
    """The spatial resolution of a Geometry in meters."""
    hasMetricVolume: NamedNode
    """The volume of a Spatial Object in cubic meters."""
    hasPerimeterLength: NamedNode
    """The length of the perimeter of a Spatial Object."""
    hasSerialization: NamedNode
    """Connects a Geometry object with its text-based serialization."""
    hasSize: NamedNode
    """Subproperties of this property are used to indicate the size of a Spatial Object as a measurement or estimate of one or more dimensions of the Spatial Object's spatial presence."""
    hasSpatialAccuracy: NamedNode
    """The positional accuracy of the coordinates of a Geometry."""
    hasSpatialResolution: NamedNode
    """The spatial resolution of a Geometry."""
    hasVolume: NamedNode
    """The volume of a three-dimensional Spatial Object."""
    isEmpty: NamedNode
    """(true) if this geometric object is the empty Geometry. If true, then this geometric object represents the empty point set for the coordinate space."""
    isSimple: NamedNode
    """(true) if this geometric object has no anomalous geometric points, such as self intersection or self tangency."""
    kmlLiteral: NamedNode
    """A KML serialization of a Geometry object."""
    rcc8dc: NamedNode
    """States that the subject SpatialObject is spatially disjoint from the object SpatialObject. DE-9IM: FFTFFTTTT"""
    rcc8ec: NamedNode
    """States that the subject SpatialObject spatially meets the object SpatialObject. DE-9IM: FFTFTTTTT"""
    rcc8eq: NamedNode
    """States that the subject SpatialObject spatially equals the object SpatialObject. DE-9IM: TFFFTFFFT"""
    rcc8ntpp: NamedNode
    """States that the subject SpatialObject is spatially inside the object SpatialObject. DE-9IM: TFFTFFTTT"""
    rcc8ntppi: NamedNode
    """States that the subject SpatialObject spatially contains the object SpatialObject. DE-9IM: TTTFFTFFT"""
    rcc8po: NamedNode
    """States that the subject SpatialObject spatially overlaps the object SpatialObject. DE-9IM: TTTTTTTTT"""
    rcc8tpp: NamedNode
    """States that the subject SpatialObject is spatially covered by the object SpatialObject. DE-9IM: TFFTTFTTT"""
    rcc8tppi: NamedNode
    """States that the subject SpatialObject spatially covers the object SpatialObject. DE-9IM: TTTFTTFFT"""
    sfContains: NamedNode
    """States that the subject SpatialObject spatially contains the object SpatialObject. DE-9IM: T*****FF*"""
    sfCrosses: NamedNode
    """States that the subject SpatialObject spatially crosses the object SpatialObject. DE-9IM: T*T******"""
    sfDisjoint: NamedNode
    """States that the subject SpatialObject is spatially disjoint from the object SpatialObject. DE-9IM: FF*FF****"""
    sfEquals: NamedNode
    """States that the subject SpatialObject spatially equals the object SpatialObject. DE-9IM: TFFFTFFFT"""
    sfIntersects: NamedNode
    """States that the subject SpatialObject is not spatially disjoint from the object SpatialObject. DE-9IM: T******** ^ *T******* ^ ***T***** ^ ****T****"""
    sfOverlaps: NamedNode
    """States that the subject SpatialObject spatially overlaps the object SpatialObject. DE-9IM: T*T***T**"""
    sfTouches: NamedNode
    """States that the subject SpatialObject spatially touches the object SpatialObject. DE-9IM: FT******* ^ F**T***** ^ F***T****"""
    sfWithin: NamedNode
    """States that the subject SpatialObject is spatially within the object SpatialObject. DE-9IM: T*F**F***"""
    spatialDimension: NamedNode
    """The number of measurements or axes needed to describe the spatial position of this Geometry in a coordinate system."""
    wktLiteral: NamedNode
    """A Well-known Text serialization of a Geometry object."""
